@@ -918,8 +918,10 @@ for i in range(numFiles):
             if showFiles == 0:
                 if data.find('No records') != -1:
                     continue
-            
-            outputFile.write(data[1:]) # skip leading space
+            if data[0] == ' ':
+                outputFile.write(data[1:]) # skip leading space
+            else:
+                outputFile.write(data)
         
     except:
         if format is None:
